Convertable

Trait Convertable 

pub trait Convertable {
    // Required methods
    fn to_base_number(&self) -> u64;
    fn convert_to_base(&self, value: u64) -> u64;
}
Handles SkSmartAttributUnit, so that we can convert whatever number to the “base” and then do formatting on that

Required Methods

fn to_base_number(&self) -> u64

fn convert_to_base(&self, value: u64) -> u64

Implementations on Foreign Types

Source

impl Convertable for SkSmartAttributeUnit

Source

fn to_base_number(&self) -> u64

Take a value and return what would need to be multiplied by the base to get the “right” value

Source

fn convert_to_base(&self, value: u64) -> u64

Convert a number of some unit to the “base” unit

Implementors