pub struct BenchmarkConfig {
pub kind: BenchmarkType,
pub block_size: usize,
pub block_count: usize,
pub file_path: Option<PathBuf>,
pub delete_after: bool,
pub random: bool,
}Expand description
The configuration for a benchmark. This nclues everything from the block size and count, to the kind of benchmark.
Fields
kind: BenchmarkTypeWhether this is a read or write benchmark
block_size: usizeBlock size in bytes
block_count: usizeBlock count
file_path: Option<PathBuf>Set a custom file path
delete_after: boolDelete the created test file after the benchmark is complete
random: boolWhether this is a sequential benchmark or a random benchmark
Implementations
Sourceimpl BenchmarkConfig
impl BenchmarkConfig
pub fn total_size(&self) -> usize